@@ -52,7 +52,7 @@ venn <- Venn(gene_list)
 data <- process_data(venn)
 items <- venn_region(data) %>%
   dplyr::rowwise() %>%
-  dplyr::mutate(text = stringr::str_wrap(paste0(.data$item, collapse = " "),
+  dplyr::mutate(text = yulab.utils::str_wrap(paste0(.data$item, collapse = " "),
                                          width = 40)) %>%
   sf::st_as_sf()
 label_coord = sf::st_centroid(items$geometry) %>% sf::st_coordinates()
